@@ -1,5 +1,7 @@
 # -*- coding: UTF-8 -*-
-from packagesample import __version__, __chicken__, log
+from packagesample import __version__
+# from packagesample import __chicken__
+from packagesample import log
 import __builtin__
 
 
